.. _prima.plugins:

================================
Plugin reference for Lino Prima
================================


.. toctree::
   :maxdepth: 1
   :glob:

   cert
   periods
   prima
   users
   school
